# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_apigatewayv2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_apigatewayv2.proto\x12\x1coak9.tython.aws.apigatewayv2\x1a\x13shared/shared.proto\"\x88\x01\n\x11\x41piBodyS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x0b\n\x03key\x18\x05 \x01(\t\"\xcb\x01\n\x07\x41piCors\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rallow_origins\x18\x02 \x03(\t\x12\x19\n\x11\x61llow_credentials\x18\x03 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x04 \x03(\t\x12\x15\n\rallow_headers\x18\x05 \x03(\t\x12\x0f\n\x07max_age\x18\x06 \x01(\x05\x12\x15\n\rallow_methods\x18\x07 \x03(\t\"\xe3\x05\n\x03\x41pi\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1aroute_selection_expression\x18\x02 \x01(\t\x12I\n\x10\x62ody_s3_location\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.apigatewayv2.ApiBodyS3Location\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tbase_path\x18\x05 \x01(\t\x12\x18\n\x10\x66\x61il_on_warnings\x18\x06 \x01(\x08\x12$\n\x1c\x64isable_execute_api_endpoint\x18\x07 \x01(\x08\x12!\n\x19\x64isable_schema_validation\x18\x08 \x01(\x08\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0e\n\x06target\x18\n \x01(\t\x12\x17\n\x0f\x63redentials_arn\x18\x0b \x01(\t\x12\x41\n\x12\x63ors_configuration\x18\x0c \x01(\x0b\x32%.oak9.tython.aws.apigatewayv2.ApiCors\x12\x0f\n\x07version\x18\r \x01(\t\x12\x15\n\rprotocol_type\x18\x0e \x01(\t\x12\x11\n\troute_key\x18\x0f \x01(\t\x12\x39\n\x04\x62ody\x18\x10 \x03(\x0b\x32+.oak9.tython.aws.apigatewayv2.Api.BodyEntry\x12\x39\n\x04tags\x18\x11 \x03(\x0b\x32+.oak9.tython.aws.apigatewayv2.Api.TagsEntry\x12$\n\x1c\x61pi_key_selection_expression\x18\x12 \x01(\t\x1a+\n\tBodyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x05\n\x0c\x41piGatewayV2\x12.\n\x03\x61pi\x18\x01 \x01(\x0b\x32!.oak9.tython.aws.apigatewayv2.Api\x12=\n\x0b\x61pi_mapping\x18\x02 \x03(\x0b\x32(.oak9.tython.aws.apigatewayv2.ApiMapping\x12<\n\nauthorizer\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.apigatewayv2.Authorizer\x12<\n\ndeployment\x18\x04 \x01(\x0b\x32(.oak9.tython.aws.apigatewayv2.Deployment\x12=\n\x0b\x64omain_name\x18\x05 \x03(\x0b\x32(.oak9.tython.aws.apigatewayv2.DomainName\x12>\n\x0bintegration\x18\x06 \x03(\x0b\x32).oak9.tython.aws.apigatewayv2.Integration\x12O\n\x14integration_response\x18\x07 \x03(\x0b\x32\x31.oak9.tython.aws.apigatewayv2.IntegrationResponse\x12\x32\n\x05model\x18\x08 \x01(\x0b\x32#.oak9.tython.aws.apigatewayv2.Model\x12\x32\n\x05route\x18\t \x03(\x0b\x32#.oak9.tython.aws.apigatewayv2.Route\x12\x43\n\x0eroute_response\x18\n \x03(\x0b\x32+.oak9.tython.aws.apigatewayv2.RouteResponse\x12\x32\n\x05stage\x18\x0b \x03(\x0b\x32#.oak9.tython.aws.apigatewayv2.Stage\"\x92\x01\n\nApiMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64omain_name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x17\n\x0f\x61pi_mapping_key\x18\x04 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x05 \x01(\t\"w\n\x1a\x41uthorizerJWTConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x10\n\x08\x61udience\x18\x03 \x03(\t\"\xc4\x03\n\nAuthorizer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1eidentity_validation_expression\x18\x02 \x01(\t\x12\x16\n\x0e\x61uthorizer_uri\x18\x03 \x01(\t\x12\"\n\x1a\x61uthorizer_credentials_arn\x18\x04 \x01(\t\x12\x17\n\x0f\x61uthorizer_type\x18\x05 \x01(\t\x12S\n\x11jwt_configuration\x18\x06 \x01(\x0b\x32\x38.oak9.tython.aws.apigatewayv2.AuthorizerJWTConfiguration\x12(\n authorizer_result_ttl_in_seconds\x18\x07 \x01(\x05\x12\x17\n\x0fidentity_source\x18\x08 \x03(\t\x12)\n!authorizer_payload_format_version\x18\t \x01(\t\x12\x1f\n\x17\x65nable_simple_responses\x18\n \x01(\x08\x12\x0e\n\x06\x61pi_id\x18\x0b \x01(\t\x12\x0c\n\x04name\x18\x0c \x01(\t\"~\n\nDeployment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nstage_name\x18\x03 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x04 \x01(\t\"\x90\x01\n!DomainNameMutualTlsAuthentication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12truststore_version\x18\x02 \x01(\t\x12\x16\n\x0etruststore_uri\x18\x03 \x01(\t\"\xbf\x01\n!DomainNameDomainNameConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fsecurity_policy\x18\x02 \x01(\t\x12\x15\n\rendpoint_type\x18\x03 \x01(\t\x12\x18\n\x10\x63\x65rtificate_name\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\x92\x03\n\nDomainName\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x19mutual_tls_authentication\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.apigatewayv2.DomainNameMutualTlsAuthentication\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x63\n\x1a\x64omain_name_configurations\x18\x04 \x03(\x0b\x32?.oak9.tython.aws.apigatewayv2.DomainNameDomainNameConfiguration\x12@\n\x04tags\x18\x05 \x03(\x0b\x32\x32.oak9.tython.aws.apigatewayv2.DomainName.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x14IntegrationTlsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15server_name_to_verify\x18\x02 \x01(\t\"\xb8\x06\n\x0bIntegration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12%\n\x1dtemplate_selection_expression\x18\x03 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x04 \x01(\t\x12\x1a\n\x12integration_method\x18\x05 \x01(\t\x12\x1c\n\x14passthrough_behavior\x18\x06 \x01(\t\x12\\\n\x12request_parameters\x18\x07 \x03(\x0b\x32@.oak9.tython.aws.apigatewayv2.Integration.RequestParametersEntry\x12\x15\n\rconnection_id\x18\x08 \x01(\t\x12\x17\n\x0fintegration_uri\x18\t \x01(\t\x12\x1e\n\x16payload_format_version\x18\n \x01(\t\x12\x17\n\x0f\x63redentials_arn\x18\x0b \x01(\t\x12Z\n\x11request_templates\x18\x0c \x03(\x0b\x32?.oak9.tython.aws.apigatewayv2.Integration.RequestTemplatesEntry\x12\x19\n\x11timeout_in_millis\x18\r \x01(\x05\x12\x46\n\ntls_config\x18\x0e \x01(\x0b\x32\x32.oak9.tython.aws.apigatewayv2.IntegrationTlsConfig\x12!\n\x19\x63ontent_handling_strategy\x18\x0f \x01(\t\x12\x1b\n\x13integration_subtype\x18\x10 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x11 \x01(\t\x12\x18\n\x10integration_type\x18\x12 \x01(\t\x1a\x38\n\x16RequestParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15RequestTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x04\n\x13IntegrationResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x64\n\x12response_templates\x18\x02 \x03(\x0b\x32H.oak9.tython.aws.apigatewayv2.IntegrationResponse.ResponseTemplatesEntry\x12%\n\x1dtemplate_selection_expression\x18\x03 \x01(\t\x12\x66\n\x13response_parameters\x18\x04 \x03(\x0b\x32I.oak9.tython.aws.apigatewayv2.IntegrationResponse.ResponseParametersEntry\x12!\n\x19\x63ontent_handling_strategy\x18\x05 \x01(\t\x12\x16\n\x0eintegration_id\x18\x06 \x01(\t\x12 \n\x18integration_response_key\x18\x07 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x08 \x01(\t\x1a\x38\n\x16ResponseTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x01\n\x05Model\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x03 \x01(\t\x12?\n\x06schema\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.apigatewayv2.Model.SchemaEntry\x12\x0e\n\x06\x61pi_id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a-\n\x0bSchemaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x04\n\x05Route\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06target\x18\x02 \x01(\t\x12+\n#route_response_selection_expression\x18\x03 \x01(\t\x12\x15\n\rauthorizer_id\x18\x04 \x01(\t\x12N\n\x0erequest_models\x18\x05 \x03(\x0b\x32\x36.oak9.tython.aws.apigatewayv2.Route.RequestModelsEntry\x12\x16\n\x0eoperation_name\x18\x06 \x01(\t\x12\x1c\n\x14\x61uthorization_scopes\x18\x07 \x03(\t\x12\x18\n\x10\x61pi_key_required\x18\x08 \x01(\x08\x12\x11\n\troute_key\x18\t \x01(\t\x12\x1a\n\x12\x61uthorization_type\x18\n \x01(\t\x12\"\n\x1amodel_selection_expression\x18\x0b \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x0c \x01(\t\x12V\n\x12request_parameters\x18\r \x03(\x0b\x32:.oak9.tython.aws.apigatewayv2.Route.RequestParametersEntry\x1a\x34\n\x12RequestModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16RequestParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd8\x03\n\rRouteResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12route_response_key\x18\x02 \x01(\t\x12`\n\x13response_parameters\x18\x03 \x03(\x0b\x32\x43.oak9.tython.aws.apigatewayv2.RouteResponse.ResponseParametersEntry\x12\x10\n\x08route_id\x18\x04 \x01(\t\x12\"\n\x1amodel_selection_expression\x18\x05 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x06 \x01(\t\x12X\n\x0fresponse_models\x18\x07 \x03(\x0b\x32?.oak9.tython.aws.apigatewayv2.RouteResponse.ResponseModelsEntry\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13ResponseModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x16StageAccessLogSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65stination_arn\x18\x03 \x01(\t\"\xe1\x01\n\x12StageRouteSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rlogging_level\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x61ta_trace_enabled\x18\x03 \x01(\x08\x12\x1e\n\x16throttling_burst_limit\x18\x04 \x01(\x05\x12 \n\x18\x64\x65tailed_metrics_enabled\x18\x05 \x01(\x08\x12\x1d\n\x15throttling_rate_limit\x18\x06 \x01(\x01\"\xe2\x05\n\x05Stage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63lient_certificate_id\x18\x02 \x01(\t\x12\x15\n\rdeployment_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12Q\n\x13\x61\x63\x63\x65ss_log_settings\x18\x05 \x01(\x0b\x32\x34.oak9.tython.aws.apigatewayv2.StageAccessLogSettings\x12\x13\n\x0b\x61uto_deploy\x18\x06 \x01(\x08\x12N\n\x0eroute_settings\x18\x07 \x03(\x0b\x32\x36.oak9.tython.aws.apigatewayv2.Stage.RouteSettingsEntry\x12\x12\n\nstage_name\x18\x08 \x01(\t\x12P\n\x0fstage_variables\x18\t \x03(\x0b\x32\x37.oak9.tython.aws.apigatewayv2.Stage.StageVariablesEntry\x12\x0e\n\x06\x61pi_id\x18\n \x01(\t\x12P\n\x16\x64\x65\x66\x61ult_route_settings\x18\x0b \x01(\x0b\x32\x30.oak9.tython.aws.apigatewayv2.StageRouteSettings\x12;\n\x04tags\x18\x0c \x03(\x0b\x32-.oak9.tython.aws.apigatewayv2.Stage.TagsEntry\x1a\x34\n\x12RouteSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13StageVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x19RouteParameterConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08required\x18\x02 \x01(\x08\"n\n!RouteResponseParameterConstraints\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08required\x18\x02 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_apigatewayv2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _API_BODYENTRY._options = None
  _API_BODYENTRY._serialized_options = b'8\001'
  _API_TAGSENTRY._options = None
  _API_TAGSENTRY._serialized_options = b'8\001'
  _DOMAINNAME_TAGSENTRY._options = None
  _DOMAINNAME_TAGSENTRY._serialized_options = b'8\001'
  _INTEGRATION_REQUESTPARAMETERSENTRY._options = None
  _INTEGRATION_REQUESTPARAMETERSENTRY._serialized_options = b'8\001'
  _INTEGRATION_REQUESTTEMPLATESENTRY._options = None
  _INTEGRATION_REQUESTTEMPLATESENTRY._serialized_options = b'8\001'
  _INTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._options = None
  _INTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_options = b'8\001'
  _INTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _INTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _MODEL_SCHEMAENTRY._options = None
  _MODEL_SCHEMAENTRY._serialized_options = b'8\001'
  _ROUTE_REQUESTMODELSENTRY._options = None
  _ROUTE_REQUESTMODELSENTRY._serialized_options = b'8\001'
  _ROUTE_REQUESTPARAMETERSENTRY._options = None
  _ROUTE_REQUESTPARAMETERSENTRY._serialized_options = b'8\001'
  _ROUTERESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _ROUTERESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _ROUTERESPONSE_RESPONSEMODELSENTRY._options = None
  _ROUTERESPONSE_RESPONSEMODELSENTRY._serialized_options = b'8\001'
  _STAGE_ROUTESETTINGSENTRY._options = None
  _STAGE_ROUTESETTINGSENTRY._serialized_options = b'8\001'
  _STAGE_STAGEVARIABLESENTRY._options = None
  _STAGE_STAGEVARIABLESENTRY._serialized_options = b'8\001'
  _STAGE_TAGSENTRY._options = None
  _STAGE_TAGSENTRY._serialized_options = b'8\001'
  _APIBODYS3LOCATION._serialized_start=82
  _APIBODYS3LOCATION._serialized_end=218
  _APICORS._serialized_start=221
  _APICORS._serialized_end=424
  _API._serialized_start=427
  _API._serialized_end=1166
  _API_BODYENTRY._serialized_start=1078
  _API_BODYENTRY._serialized_end=1121
  _API_TAGSENTRY._serialized_start=1123
  _API_TAGSENTRY._serialized_end=1166
  _APIGATEWAYV2._serialized_start=1169
  _APIGATEWAYV2._serialized_end=1851
  _APIMAPPING._serialized_start=1854
  _APIMAPPING._serialized_end=2000
  _AUTHORIZERJWTCONFIGURATION._serialized_start=2002
  _AUTHORIZERJWTCONFIGURATION._serialized_end=2121
  _AUTHORIZER._serialized_start=2124
  _AUTHORIZER._serialized_end=2576
  _DEPLOYMENT._serialized_start=2578
  _DEPLOYMENT._serialized_end=2704
  _DOMAINNAMEMUTUALTLSAUTHENTICATION._serialized_start=2707
  _DOMAINNAMEMUTUALTLSAUTHENTICATION._serialized_end=2851
  _DOMAINNAMEDOMAINNAMECONFIGURATION._serialized_start=2854
  _DOMAINNAMEDOMAINNAMECONFIGURATION._serialized_end=3045
  _DOMAINNAME._serialized_start=3048
  _DOMAINNAME._serialized_end=3450
  _DOMAINNAME_TAGSENTRY._serialized_start=1123
  _DOMAINNAME_TAGSENTRY._serialized_end=1166
  _INTEGRATIONTLSCONFIG._serialized_start=3452
  _INTEGRATIONTLSCONFIG._serialized_end=3562
  _INTEGRATION._serialized_start=3565
  _INTEGRATION._serialized_end=4389
  _INTEGRATION_REQUESTPARAMETERSENTRY._serialized_start=4276
  _INTEGRATION_REQUESTPARAMETERSENTRY._serialized_end=4332
  _INTEGRATION_REQUESTTEMPLATESENTRY._serialized_start=4334
  _INTEGRATION_REQUESTTEMPLATESENTRY._serialized_end=4389
  _INTEGRATIONRESPONSE._serialized_start=4392
  _INTEGRATIONRESPONSE._serialized_end=4941
  _INTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_start=4826
  _INTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_end=4882
  _INTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=4884
  _INTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=4941
  _MODEL._serialized_start=4944
  _MODEL._serialized_end=5193
  _MODEL_SCHEMAENTRY._serialized_start=5148
  _MODEL_SCHEMAENTRY._serialized_end=5193
  _ROUTE._serialized_start=5196
  _ROUTE._serialized_end=5803
  _ROUTE_REQUESTMODELSENTRY._serialized_start=5693
  _ROUTE_REQUESTMODELSENTRY._serialized_end=5745
  _ROUTE_REQUESTPARAMETERSENTRY._serialized_start=4276
  _ROUTE_REQUESTPARAMETERSENTRY._serialized_end=4332
  _ROUTERESPONSE._serialized_start=5806
  _ROUTERESPONSE._serialized_end=6278
  _ROUTERESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=4884
  _ROUTERESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=4941
  _ROUTERESPONSE_RESPONSEMODELSENTRY._serialized_start=6225
  _ROUTERESPONSE_RESPONSEMODELSENTRY._serialized_end=6278
  _STAGEACCESSLOGSETTINGS._serialized_start=6280
  _STAGEACCESSLOGSETTINGS._serialized_end=6402
  _STAGEROUTESETTINGS._serialized_start=6405
  _STAGEROUTESETTINGS._serialized_end=6630
  _STAGE._serialized_start=6633
  _STAGE._serialized_end=7371
  _STAGE_ROUTESETTINGSENTRY._serialized_start=7219
  _STAGE_ROUTESETTINGSENTRY._serialized_end=7271
  _STAGE_STAGEVARIABLESENTRY._serialized_start=7273
  _STAGE_STAGEVARIABLESENTRY._serialized_end=7326
  _STAGE_TAGSENTRY._serialized_start=1123
  _STAGE_TAGSENTRY._serialized_end=1166
  _ROUTEPARAMETERCONSTRAINTS._serialized_start=7373
  _ROUTEPARAMETERCONSTRAINTS._serialized_end=7475
  _ROUTERESPONSEPARAMETERCONSTRAINTS._serialized_start=7477
  _ROUTERESPONSEPARAMETERCONSTRAINTS._serialized_end=7587
# @@protoc_insertion_point(module_scope)



import os
import unittest
from nose.tools import assert_equal
from parameterized import parameterized

from core.bp_metadata_utils.policy import Policy, PolicyProvider
from core.bp_metadata_utils.policy_implementation_docstring import PolicyImplementationDocstring

this_dir = os.path.dirname(os.path.abspath(__file__))
test_data_path = os.path.join(this_dir, 'testdata', 'oak9')


class TestPolicyImplementation(unittest.TestCase):
    @parameterized.expand([
        (
                'well_formed_implements_field_single_value_with_a_space_after_implements.py',
                [
                    Policy(
                        name='',
                        description='',
                        provider=PolicyProvider.AZURE_POLICY,
                        url='https://github.com/Azure/azure-policy/blob/master/built-in-policies/policyDefinitions/Kubernetes/AKS_EncryptionAtHost_Deny.json',
                    ),
                ]
        ),
        (
                'well_formed_implements_field_single_value_with_a_space_after_implements.py',
                [
                    Policy(
                        name='',
                        description='',
                        provider=PolicyProvider.AZURE_POLICY,
                        url='https://github.com/Azure/azure-policy/blob/master/built-in-policies/policyDefinitions/Kubernetes/AKS_EncryptionAtHost_Deny.json',
                    ),
                ]
        ),
        (
                'well_formed_aws_config_implementation.py',
                [
                    Policy(
                        name='',
                        description='',
                        provider=PolicyProvider.AWS_CONFIG_POLICY,
                        url='https://github.com/awslabs/aws-config-rules/blob/master/python/API_GW_EXECUTION_LOGGING_ENABLED/API_GW_EXECUTION_LOGGING_ENABLED.py',
                    ),
                ]
        ),
        (
                'well_formed_implements_field_multiple_values.py',
                [


                    Policy(
                        name='',
                        description='',
                        provider=PolicyProvider.AZURE_POLICY,
                        url='https://github.com/Azure/azure-policy/blob/master/built-in-policies/policyDefinitions/Kubernetes/AKS_EncryptionAtHost_Deny.json',
                    ),
                    Policy(
                        name='',
                        description='',
                        provider=PolicyProvider.KUBE_BENCH,
                        url='https://github.com/aquasecurity/blob/master/kube-bench/cfg/cis-1.6/master.yaml',
                    ),
                ]
        ),
        (
                'empty_implements_field.py',
                []
        ),
        (
                'no_implements_field.py',
                []
        ),
    ])
    def test_policy_implementations(self, source_file, want):
        with open(os.path.join(test_data_path, source_file)) as f:
            source = f.read()
            docstring = PolicyImplementationDocstring(source)

            assert_equal(list(docstring.implementations), want)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_sso.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_sso.proto\x12\x13oak9.tython.aws.sso\x1a\x13shared/shared.proto\"\xcd\x01\n\nAssignment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinstance_arn\x18\x02 \x01(\t\x12\x11\n\ttarget_id\x18\x03 \x01(\t\x12\x13\n\x0btarget_type\x18\x04 \x01(\t\x12\x1a\n\x12permission_set_arn\x18\x05 \x01(\t\x12\x16\n\x0eprincipal_type\x18\x06 \x01(\t\x12\x14\n\x0cprincipal_id\x18\x07 \x01(\t\"v\n\x03SSO\x12\x33\n\nassignment\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.sso.Assignment\x12:\n\x0epermission_set\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.sso.PermissionSet\"\xcf\x02\n\rPermissionSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cinstance_arn\x18\x04 \x01(\t\x12\x18\n\x10session_duration\x18\x05 \x01(\t\x12\x18\n\x10relay_state_type\x18\x06 \x01(\t\x12\x18\n\x10managed_policies\x18\x07 \x03(\t\x12\x15\n\rinline_policy\x18\x08 \x01(\t\x12:\n\x04tags\x18\t \x03(\x0b\x32,.oak9.tython.aws.sso.PermissionSet.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_sso_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PERMISSIONSET_TAGSENTRY._options = None
  _PERMISSIONSET_TAGSENTRY._serialized_options = b'8\001'
  _ASSIGNMENT._serialized_start=64
  _ASSIGNMENT._serialized_end=269
  _SSO._serialized_start=271
  _SSO._serialized_end=389
  _PERMISSIONSET._serialized_start=392
  _PERMISSIONSET._serialized_end=727
  _PERMISSIONSET_TAGSENTRY._serialized_start=684
  _PERMISSIONSET_TAGSENTRY._serialized_end=727
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.autoscaling.v2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.api import resource_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5kubernetes/kubernetes_io.k8s.api.autoscaling.v2.proto\x12\"oak9.tython.k8s.api.autoscaling.v2\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.api.resource.proto\"\xbb\x01\n\x1d\x43ontainerResourceMetricSource\x12\x11\n\tcontainer\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12@\n\x06target\x18\x03 \x01(\x0b\x32\x30.oak9.tython.k8s.api.autoscaling.v2.MetricTarget\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc1\x01\n\x1d\x43ontainerResourceMetricStatus\x12\x11\n\tcontainer\x18\x01 \x01(\t\x12\x46\n\x07\x63urrent\x18\x02 \x01(\x0b\x32\x35.oak9.tython.k8s.api.autoscaling.v2.MetricValueStatus\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x87\x01\n\x1b\x43rossVersionObjectReference\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd7\x01\n\x14\x45xternalMetricSource\x12\x44\n\x06metric\x18\x01 \x01(\x0b\x32\x34.oak9.tython.k8s.api.autoscaling.v2.MetricIdentifier\x12@\n\x06target\x18\x02 \x01(\x0b\x32\x30.oak9.tython.k8s.api.autoscaling.v2.MetricTarget\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdd\x01\n\x14\x45xternalMetricStatus\x12\x46\n\x07\x63urrent\x18\x01 \x01(\x0b\x32\x35.oak9.tython.k8s.api.autoscaling.v2.MetricValueStatus\x12\x44\n\x06metric\x18\x02 \x01(\x0b\x32\x34.oak9.tython.k8s.api.autoscaling.v2.MetricIdentifier\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x80\x01\n\x10HPAScalingPolicy\x12\x16\n\x0eperiod_seconds\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x05\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcf\x01\n\x0fHPAScalingRules\x12\x46\n\x08policies\x18\x01 \x03(\x0b\x32\x34.oak9.tython.k8s.api.autoscaling.v2.HPAScalingPolicy\x12\x15\n\rselect_policy\x18\x02 \x01(\t\x12$\n\x1cstabilization_window_seconds\x18\x03 \x01(\x05\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe4\x02\n\x17HorizontalPodAutoscaler\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12M\n\x04spec\x18\x04 \x01(\x0b\x32?.oak9.tython.k8s.api.autoscaling.v2.HorizontalPodAutoscalerSpec\x12Q\n\x06status\x18\x05 \x01(\x0b\x32\x41.oak9.tython.k8s.api.autoscaling.v2.HorizontalPodAutoscalerStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xea\x01\n\x1fHorizontalPodAutoscalerBehavior\x12G\n\nscale_down\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.api.autoscaling.v2.HPAScalingRules\x12\x45\n\x08scale_up\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.api.autoscaling.v2.HPAScalingRules\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n HorizontalPodAutoscalerCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x90\x02\n\x1bHorizontalPodAutoscalerList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12J\n\x05items\x18\x02 \x03(\x0b\x32;.oak9.tython.k8s.api.autoscaling.v2.HorizontalPodAutoscaler\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf5\x02\n\x1bHorizontalPodAutoscalerSpec\x12U\n\x08\x62\x65havior\x18\x01 \x01(\x0b\x32\x43.oak9.tython.k8s.api.autoscaling.v2.HorizontalPodAutoscalerBehavior\x12\x14\n\x0cmax_replicas\x18\x02 \x01(\x05\x12?\n\x07metrics\x18\x03 \x03(\x0b\x32..oak9.tython.k8s.api.autoscaling.v2.MetricSpec\x12\x14\n\x0cmin_replicas\x18\x04 \x01(\x05\x12Y\n\x10scale_target_ref\x18\x05 \x01(\x0b\x32?.oak9.tython.k8s.api.autoscaling.v2.CrossVersionObjectReference\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9c\x03\n\x1dHorizontalPodAutoscalerStatus\x12X\n\nconditions\x18\x01 \x03(\x0b\x32\x44.oak9.tython.k8s.api.autoscaling.v2.HorizontalPodAutoscalerCondition\x12I\n\x0f\x63urrent_metrics\x18\x02 \x03(\x0b\x32\x30.oak9.tython.k8s.api.autoscaling.v2.MetricStatus\x12\x18\n\x10\x63urrent_replicas\x18\x03 \x01(\x05\x12\x18\n\x10\x64\x65sired_replicas\x18\x04 \x01(\x05\x12L\n\x0flast_scale_time\x18\x05 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x1b\n\x13observed_generation\x18\x06 \x01(\x05\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa9\x01\n\x10MetricIdentifier\x12\x0c\n\x04name\x18\x01 \x01(\t\x12N\n\x08selector\x18\x02 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd6\x03\n\nMetricSpec\x12]\n\x12\x63ontainer_resource\x18\x01 \x01(\x0b\x32\x41.oak9.tython.k8s.api.autoscaling.v2.ContainerResourceMetricSource\x12J\n\x08\x65xternal\x18\x02 \x01(\x0b\x32\x38.oak9.tython.k8s.api.autoscaling.v2.ExternalMetricSource\x12\x46\n\x06object\x18\x03 \x01(\x0b\x32\x36.oak9.tython.k8s.api.autoscaling.v2.ObjectMetricSource\x12\x42\n\x04pods\x18\x04 \x01(\x0b\x32\x34.oak9.tython.k8s.api.autoscaling.v2.PodsMetricSource\x12J\n\x08resource\x18\x05 \x01(\x0b\x32\x38.oak9.tython.k8s.api.autoscaling.v2.ResourceMetricSource\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd8\x03\n\x0cMetricStatus\x12]\n\x12\x63ontainer_resource\x18\x01 \x01(\x0b\x32\x41.oak9.tython.k8s.api.autoscaling.v2.ContainerResourceMetricStatus\x12J\n\x08\x65xternal\x18\x02 \x01(\x0b\x32\x38.oak9.tython.k8s.api.autoscaling.v2.ExternalMetricStatus\x12\x46\n\x06object\x18\x03 \x01(\x0b\x32\x36.oak9.tython.k8s.api.autoscaling.v2.ObjectMetricStatus\x12\x42\n\x04pods\x18\x04 \x01(\x0b\x32\x34.oak9.tython.k8s.api.autoscaling.v2.PodsMetricStatus\x12J\n\x08resource\x18\x05 \x01(\x0b\x32\x38.oak9.tython.k8s.api.autoscaling.v2.ResourceMetricStatus\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x02\n\x0cMetricTarget\x12\x1b\n\x13\x61verage_utilization\x18\x01 \x01(\x05\x12N\n\raverage_value\x18\x02 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x46\n\x05value\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x02\n\x11MetricValueStatus\x12\x1b\n\x13\x61verage_utilization\x18\x01 \x01(\x05\x12N\n\raverage_value\x18\x02 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12\x46\n\x05value\x18\x03 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x02\n\x12ObjectMetricSource\x12Y\n\x10\x64\x65scribed_object\x18\x01 \x01(\x0b\x32?.oak9.tython.k8s.api.autoscaling.v2.CrossVersionObjectReference\x12\x44\n\x06metric\x18\x02 \x01(\x0b\x32\x34.oak9.tython.k8s.api.autoscaling.v2.MetricIdentifier\x12@\n\x06target\x18\x03 \x01(\x0b\x32\x30.oak9.tython.k8s.api.autoscaling.v2.MetricTarget\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb6\x02\n\x12ObjectMetricStatus\x12\x46\n\x07\x63urrent\x18\x01 \x01(\x0b\x32\x35.oak9.tython.k8s.api.autoscaling.v2.MetricValueStatus\x12Y\n\x10\x64\x65scribed_object\x18\x02 \x01(\x0b\x32?.oak9.tython.k8s.api.autoscaling.v2.CrossVersionObjectReference\x12\x44\n\x06metric\x18\x03 \x01(\x0b\x32\x34.oak9.tython.k8s.api.autoscaling.v2.MetricIdentifier\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd3\x01\n\x10PodsMetricSource\x12\x44\n\x06metric\x18\x01 \x01(\x0b\x32\x34.oak9.tython.k8s.api.autoscaling.v2.MetricIdentifier\x12@\n\x06target\x18\x02 \x01(\x0b\x32\x30.oak9.tython.k8s.api.autoscaling.v2.MetricTarget\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd9\x01\n\x10PodsMetricStatus\x12\x46\n\x07\x63urrent\x18\x01 \x01(\x0b\x32\x35.oak9.tython.k8s.api.autoscaling.v2.MetricValueStatus\x12\x44\n\x06metric\x18\x02 \x01(\x0b\x32\x34.oak9.tython.k8s.api.autoscaling.v2.MetricIdentifier\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9f\x01\n\x14ResourceMetricSource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x06target\x18\x02 \x01(\x0b\x32\x30.oak9.tython.k8s.api.autoscaling.v2.MetricTarget\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa5\x01\n\x14ResourceMetricStatus\x12\x46\n\x07\x63urrent\x18\x01 \x01(\x0b\x32\x35.oak9.tython.k8s.api.autoscaling.v2.MetricValueStatus\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.autoscaling.v2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONTAINERRESOURCEMETRICSOURCE._serialized_start=247
  _CONTAINERRESOURCEMETRICSOURCE._serialized_end=434
  _CONTAINERRESOURCEMETRICSTATUS._serialized_start=437
  _CONTAINERRESOURCEMETRICSTATUS._serialized_end=630
  _CROSSVERSIONOBJECTREFERENCE._serialized_start=633
  _CROSSVERSIONOBJECTREFERENCE._serialized_end=768
  _EXTERNALMETRICSOURCE._serialized_start=771
  _EXTERNALMETRICSOURCE._serialized_end=986
  _EXTERNALMETRICSTATUS._serialized_start=989
  _EXTERNALMETRICSTATUS._serialized_end=1210
  _HPASCALINGPOLICY._serialized_start=1213
  _HPASCALINGPOLICY._serialized_end=1341
  _HPASCALINGRULES._serialized_start=1344
  _HPASCALINGRULES._serialized_end=1551
  _HORIZONTALPODAUTOSCALER._serialized_start=1554
  _HORIZONTALPODAUTOSCALER._serialized_end=1910
  _HORIZONTALPODAUTOSCALERBEHAVIOR._serialized_start=1913
  _HORIZONTALPODAUTOSCALERBEHAVIOR._serialized_end=2147
  _HORIZONTALPODAUTOSCALERCONDITION._serialized_start=2150
  _HORIZONTALPODAUTOSCALERCONDITION._serialized_end=2387
  _HORIZONTALPODAUTOSCALERLIST._serialized_start=2390
  _HORIZONTALPODAUTOSCALERLIST._serialized_end=2662
  _HORIZONTALPODAUTOSCALERSPEC._serialized_start=2665
  _HORIZONTALPODAUTOSCALERSPEC._serialized_end=3038
  _HORIZONTALPODAUTOSCALERSTATUS._serialized_start=3041
  _HORIZONTALPODAUTOSCALERSTATUS._serialized_end=3453
  _METRICIDENTIFIER._serialized_start=3456
  _METRICIDENTIFIER._serialized_end=3625
  _METRICSPEC._serialized_start=3628
  _METRICSPEC._serialized_end=4098
  _METRICSTATUS._serialized_start=4101
  _METRICSTATUS._serialized_end=4573
  _METRICTARGET._serialized_start=4576
  _METRICTARGET._serialized_end=4842
  _METRICVALUESTATUS._serialized_start=4845
  _METRICVALUESTATUS._serialized_end=5102
  _OBJECTMETRICSOURCE._serialized_start=5105
  _OBJECTMETRICSOURCE._serialized_end=5409
  _OBJECTMETRICSTATUS._serialized_start=5412
  _OBJECTMETRICSTATUS._serialized_end=5722
  _PODSMETRICSOURCE._serialized_start=5725
  _PODSMETRICSOURCE._serialized_end=5936
  _PODSMETRICSTATUS._serialized_start=5939
  _PODSMETRICSTATUS._serialized_end=6156
  _RESOURCEMETRICSOURCE._serialized_start=6159
  _RESOURCEMETRICSOURCE._serialized_end=6318
  _RESOURCEMETRICSTATUS._serialized_start=6321
  _RESOURCEMETRICSTATUS._serialized_end=6486
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_org.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_org.proto\x12\x13oak9.tython.gcp.org\x1a\x13shared/shared.proto\"p\n$OrgPolicyPolicyXSpecXRulesXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"R\n!OrgPolicyPolicyXSpecXRulesXValues\x12\x16\n\x0e\x61llowed_values\x18\x01 \x03(\t\x12\x15\n\rdenied_values\x18\x02 \x03(\t\"\xe8\x01\n\x1aOrgPolicyPolicyXSpecXRules\x12\x11\n\tallow_all\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65ny_all\x18\x02 \x01(\t\x12\x0f\n\x07\x65nforce\x18\x03 \x01(\t\x12L\n\tcondition\x18\x04 \x01(\x0b\x32\x39.oak9.tython.gcp.org.OrgPolicyPolicyXSpecXRulesXCondition\x12\x46\n\x06values\x18\x05 \x01(\x0b\x32\x36.oak9.tython.gcp.org.OrgPolicyPolicyXSpecXRulesXValues\"\xa5\x01\n\x14OrgPolicyPolicyXSpec\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x1b\n\x13inherit_from_parent\x18\x02 \x01(\x08\x12\r\n\x05reset\x18\x03 \x01(\x08\x12\x13\n\x0bupdate_time\x18\x04 \x01(\t\x12>\n\x05rules\x18\x05 \x03(\x0b\x32/.oak9.tython.gcp.org.OrgPolicyPolicyXSpecXRules\"J\n\x18OrgPolicyPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xee\x01\n\x0fOrgPolicyPolicy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06parent\x18\x03 \x01(\t\x12\x37\n\x04spec\x18\x04 \x01(\x0b\x32).oak9.tython.gcp.org.OrgPolicyPolicyXSpec\x12?\n\x08timeouts\x18\x05 \x01(\x0b\x32-.oak9.tython.gcp.org.OrgPolicyPolicyXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_org_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ORGPOLICYPOLICYXSPECXRULESXCONDITION._serialized_start=63
  _ORGPOLICYPOLICYXSPECXRULESXCONDITION._serialized_end=175
  _ORGPOLICYPOLICYXSPECXRULESXVALUES._serialized_start=177
  _ORGPOLICYPOLICYXSPECXRULESXVALUES._serialized_end=259
  _ORGPOLICYPOLICYXSPECXRULES._serialized_start=262
  _ORGPOLICYPOLICYXSPECXRULES._serialized_end=494
  _ORGPOLICYPOLICYXSPEC._serialized_start=497
  _ORGPOLICYPOLICYXSPEC._serialized_end=662
  _ORGPOLICYPOLICYXTIMEOUTS._serialized_start=664
  _ORGPOLICYPOLICYXTIMEOUTS._serialized_end=738
  _ORGPOLICYPOLICY._serialized_start=741
  _ORGPOLICYPOLICY._serialized_end=979
# @@protoc_insertion_point(module_scope)
